"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PostgresConnection = void 0;
const core_connection_1 = require("@lindorm-io/core-connection");
const pg_1 = require("pg");
class PostgresConnection extends core_connection_1.ConnectionBase {
    custom;
    constructor(options, logger) {
        const { connectInterval, connectTimeout, custom, host = "localhost", port = 5432, ...connectOptions } = options;
        super({
            connectInterval,
            connectTimeout,
            connectOptions: {
                host,
                port,
                min: 1,
                max: 5,
                ...connectOptions,
            },
            type: "postgres",
        }, logger);
        this.custom = custom;
    }
    async createClientConnection() {
        if (this.custom) {
            return new this.custom(this.connectOptions);
        }
        return new pg_1.Pool(this.connectOptions);
    }
    async connectCallback() {
    }
    async disconnectCallback() {
        await this.client.end();
    }
    async query(queryTextOrConfig, values) {
        const client = await this.client.connect();
        this.logger.debug("Query", { query: queryTextOrConfig, values });
        try {
            return await client.query(queryTextOrConfig, values);
        }
        finally {
            client.release();
        }
    }
}
exports.PostgresConnection = PostgresConnection;
//# sourceMappingURL=PostgresConnection.js.map